==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectNodealias.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnodealias_h
#define objectnodealias_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_nodealias {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  char* _name;
  int _name_isdefault : 1;
  p_node _node;
  int _node_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectNode.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_nodealias_getuid (p_nodealias mynodealias);
win32_interface gboolean adms_nodealias_cmp (p_nodealias mynodealias,p_nodealias refnodealias);
win32_interface p_nodealias adms_nodealias_new_1 (p_module mymodule,char* myname);
#define adms_nodealias_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_nodealias_free(item)\
{\
  free(item->_name);\
  free(item);\
}
win32_interface p_adms adms_nodealias_new_impl (p_adms arguments[]);
win32_interface p_nodealias adms_nodealias_impl (void* member);
#define adms_nodealias(member) ((p_nodealias) (member))
#define adms_nodealias_new adms_nodealias_new_1
#define adms_nodealias_isdefault_module(nodealias) (adms_nodealias(nodealias)->_module_isdefault)
#define adms_nodealias_valueof_module(nodealias) (adms_nodealias(nodealias)->_module)
#define adms_nodealias_isdefault_name(nodealias) (adms_nodealias(nodealias)->_name_isdefault)
#define adms_nodealias_valueof_name(nodealias) (adms_nodealias(nodealias)->_name)
#define adms_nodealias_isdefault_node(nodealias) (adms_nodealias(nodealias)->_node_isdefault)
#define adms_nodealias_valueof_node(nodealias) (adms_nodealias(nodealias)->_node)
#define adms_nodealias_valueof_adms(nodealias) ((p_adms)nodealias)
#define adms_nodealias_valueto_module(a,b) ((p_nodealias)a)->_module=(b)
win32_interface void adms_nodealias_valueto_module_impl (p_nodealias mynodealias,p_module _module);
#define adms_nodealias_valueto_name(a,b) ((p_nodealias)a)->_name=(b)
win32_interface void adms_nodealias_valueto_name_impl (p_nodealias mynodealias,char* _name);
#define adms_nodealias_valueto_node(a,b) ((p_nodealias)a)->_node=(b)
win32_interface void adms_nodealias_valueto_node_impl (p_nodealias mynodealias,p_node _node);
#endif /* objectnodealias_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectNodealias.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnodealias_h
#define objectnodealias_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_nodealias {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_quark _name;
  int _name_isdefault : 1;
  p_node _node;
  int _node_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectQuark.h>
#include <admsObject/objectNode.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_nodealias_uid (p_nodealias mynodealias);
win32_interface int adms_nodealias_cmp (p_nodealias mynodealias,p_nodealias refnodealias);
win32_interface p_nodealias adms_nodealias_new(p_module mymodule,p_quark myname);
win32_interface p_adms adms_nodealias_new_impl (p_adms arguments[]);
#define adms_nodealias(member) ((p_nodealias) (member))
#define adms_nodealias_isdefault_module(nodealias) (adms_nodealias(nodealias)->_module_isdefault)
#define adms_nodealias_valueof_module(nodealias) (adms_nodealias(nodealias)->_module)
#define adms_nodealias_isdefault_name(nodealias) (adms_nodealias(nodealias)->_name_isdefault)
#define adms_nodealias_valueof_name(nodealias) (adms_nodealias(nodealias)->_name)
#define adms_nodealias_isdefault_node(nodealias) (adms_nodealias(nodealias)->_node_isdefault)
#define adms_nodealias_valueof_node(nodealias) (adms_nodealias(nodealias)->_node)
#define adms_nodealias_valueof_adms(nodealias) ((p_adms)nodealias)
win32_interface inline void adms_nodealias_valueto_module (p_nodealias mynodealias,p_module _module);
win32_interface inline void adms_nodealias_valueto_name (p_nodealias mynodealias,p_quark _name);
win32_interface inline void adms_nodealias_valueto_node (p_nodealias mynodealias,p_node _node);
win32_interface inline void adms_nodealias_free(p_nodealias mynodealias);
#endif /* objectnodealias_h */
